@@ -3,6 +3,7 @@ use core::cmp::{Eq, Ord, Ordering, PartialEq};
 use core::fmt::{self, Debug, Formatter};
 use core::hash::{Hash, Hasher};
 use core::iter::FromIterator;
+use core::mem::MaybeUninit;
 use core::ops::{
   Deref, DerefMut, Index, IndexMut, Range, RangeFrom, RangeFull, RangeInclusive, RangeTo,
   RangeToInclusive,
@@ -10,7 +11,7 @@ use core::ops::{
 use core::ptr;
 
 use crate::heap::StaticHeap;
-use crate::iterators::*;
+use crate::iterators::{StaticVecIntoIter, StaticVecIterConst, StaticVecIterMut};
 use crate::string::StaticString;
 use crate::utils::{partial_compare, slice_from_raw_parts, slice_from_raw_parts_mut};
 use crate::StaticVec;
@@ -189,15 +190,53 @@ impl<'a, T: 'a + Copy, I: IntoIterator<Item = &'a T>, const N: usize> ExtendEx<&
   impl_from_iter_ex!(val, (*val));
 }
 
-impl<'a, T: 'a + Copy, const N: usize> ExtendEx<&'a T, &StaticVec<T, N>> for StaticVec<T, N> {
-  #[inline(always)]
-  default fn extend_ex(&mut self, iter: &StaticVec<T, N>) {
-    self.extend_from_slice(iter);
+impl<T, const N1: usize, const N2: usize> ExtendEx<T, StaticVec<T, N1>> for StaticVec<T, N2> {
+  #[inline]
+  default fn extend_ex(&mut self, iter: StaticVec<T, N1>) {
+    // We just reuse most of the `extend_from_slice` code here.
+    let old_length = self.length;
+    let added_length = iter.len().min(N2 - old_length);
+    // Safety: added_length is <= our remaining capacity and `iter.len()`.
+    unsafe {
+      iter
+        .as_ptr()
+        .copy_to_nonoverlapping(self.mut_ptr_at_unchecked(old_length), added_length);
+      self.set_len(old_length + added_length);
+      // Wrap the values in a MaybeUninit to inhibit their destructors (if any),
+      // then manually drop any excess ones. This is the same kind of "trick" as
+      // is used in `new_from_array`, as you may or may not have noticed.
+      let mut forgotten = MaybeUninit::new(iter);
+      ptr::drop_in_place(
+        forgotten
+          .get_mut()
+          .as_mut_slice()
+          .get_unchecked_mut(N1.min(N2)..N1),
+      );
+    }
   }
 
-  #[inline(always)]
-  default fn from_iter_ex(iter: &StaticVec<T, N>) -> Self {
-    Self::new_from_slice(iter)
+  #[inline]
+  default fn from_iter_ex(iter: StaticVec<T, N1>) -> Self {
+    Self {
+      data: {
+        unsafe {
+          let mut data = Self::new_data_uninit();
+          iter
+            .as_ptr()
+            .copy_to_nonoverlapping(Self::first_ptr_mut(&mut data), N1.min(N2));
+          // Same thing as above here.
+          let mut forgotten = MaybeUninit::new(iter);
+          ptr::drop_in_place(
+            forgotten
+              .get_mut()
+              .as_mut_slice()
+              .get_unchecked_mut(N1.min(N2)..N1),
+          );
+          data
+        }
+      },
+      length: N1.min(N2),
+    }
   }
 }
 
@@ -215,17 +254,15 @@ impl<'a, T: 'a + Copy, const N1: usize, const N2: usize> ExtendEx<&'a T, &Static
   }
 }
 
-impl<'a, T: 'a + Copy, const N: usize> ExtendEx<&'a T, StaticVecIterConst<'a, T, N>>
-  for StaticVec<T, N>
-{
+impl<'a, T: 'a + Copy, const N: usize> ExtendEx<&'a T, &StaticVec<T, N>> for StaticVec<T, N> {
   #[inline(always)]
-  default fn extend_ex(&mut self, iter: StaticVecIterConst<'a, T, N>) {
-    self.extend_from_slice(iter.as_slice());
+  fn extend_ex(&mut self, iter: &StaticVec<T, N>) {
+    self.extend_from_slice(iter);
   }
 
   #[inline(always)]
-  default fn from_iter_ex(iter: StaticVecIterConst<'a, T, N>) -> Self {
-    Self::new_from_slice(iter.as_slice())
+  fn from_iter_ex(iter: &StaticVec<T, N>) -> Self {
+    Self::new_from_slice(iter)
   }
 }
 
@@ -243,6 +280,20 @@ impl<'a, T: 'a + Copy, const N1: usize, const N2: usize>
   }
 }
 
+impl<'a, T: 'a + Copy, const N: usize> ExtendEx<&'a T, StaticVecIterConst<'a, T, N>>
+  for StaticVec<T, N>
+{
+  #[inline(always)]
+  fn extend_ex(&mut self, iter: StaticVecIterConst<'a, T, N>) {
+    self.extend_from_slice(iter.as_slice());
+  }
+
+  #[inline(always)]
+  fn from_iter_ex(iter: StaticVecIterConst<'a, T, N>) -> Self {
+    Self::new_from_slice(iter.as_slice())
+  }
+}
+
 impl<'a, T: 'a + Copy, const N: usize> ExtendEx<&'a T, core::slice::Iter<'a, T>>
   for StaticVec<T, N>
 {
@@ -353,6 +404,13 @@ impl<T: Copy, const N: usize> From<&mut [T; N]> for StaticVec<T, N> {
   }
 }
 
+impl<T, const N1: usize, const N2: usize> From<StaticHeap<T, N1>> for StaticVec<T, N2> {
+  #[inline(always)]
+  default fn from(heap: StaticHeap<T, N1>) -> StaticVec<T, N2> {
+    StaticVec::from_iter(heap.data)
+  }
+}
+
 impl<T, const N: usize> From<StaticHeap<T, N>> for StaticVec<T, N> {
   #[inline(always)]
   fn from(heap: StaticHeap<T, N>) -> StaticVec<T, N> {
